@@ -51,40 +51,55 @@ def categorical_visual(x, y, data, kind, hue=None):
 def categorical_multivariate_visual(x, y, hue, data, kind):
     sns.catplot(x, y, hue, data, kind=kind)
 
-
 def continuous_visual(df, target):
-    rows = np.ceil(len(df.select_dtypes('float').columns-1)/2)
-    cols = 2
-    # fig, axes = plt.subplots(rows,cols,figsize=(16,6))
-    df_float = df.select_dtypes('float')
-    for i in df_float:
-        # axes[0] =
-        plt.subplot(rows, cols, i+1)
-        plt.imshow(df_float[i])
+    sns.set(rc={'figure.figsize': (16, 10)})
+    df_float = df.select_dtypes(['float', 'int'])
+    for i, n in enumerate(df_float):
+        sns.boxplot(y=target, x=df[n], data=df)
         plt.show()
 
 # -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 
+def chi2_test(df_cat, target_name):
+    chi2_summary = []
+    for i in df_cat:
+        (chi2, p, dof, _) = chi2_contingency(
+            pd.crosstab(df_cat[target_name], df_cat[i]))
+        score_to_add = {}
+        score_to_add['var'] = i
+        score_to_add['chi_square_stat'] = chi2
+        score_to_add['p-value'] = p
+        score_to_add['dof'] = dof
+        chi2_summary.append(score_to_add)
+    df_chi2 = pd.DataFrame(chi2_summary)
+    df_chi2
 
-def chi2_test():
-    pass
-
-
-def pbs_test():
+def pbs_test(df_num, target_name):
     num_summary = []
     for i in df_num:
-        pbs = pointbiserialr(df_num[i], df_num[target])
+        pbs = pointbiserialr(df_num[i], df_num[target_name])
         score_to_add = {}
         score_to_add['var'] = i
         score_to_add['pbs corr'] = pbs[0]
         score_to_add['pbs p-value'] = pbs[1]
         num_summary.append(score_to_add)
     df_num = pd.DataFrame(num_summary)
-    df_num
+
+    return df_num
 
 
-def pearson_test():
-    pass
+def pearson_test(df_num, target_name):
+    num_summary = []
+    for i in df_num:
+        pbs = perasonr(df_num[i], df_num[target_name])
+        score_to_add = {}
+        score_to_add['var'] = i
+        score_to_add['pearson corr'] = pbs[0]
+        score_to_add['pearson p-value'] = pbs[1]
+        num_summary.append(score_to_add)
+    df_num = pd.DataFrame(num_summary)
+
+    return df_num
 
 
 def outlier_treatment():  # maybe don't need this
